ComponentsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @CopyWith.new()
  • @immutable

Constructors

ComponentsResponse({required ComponentsMeta meta})
const
ComponentsResponse.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → _$ComponentsResponseCWProxy

Available on ComponentsResponse, provided by the $ComponentsResponseCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfComponentsResponse.copyWith(...) or instanceOfComponentsResponse.copyWith.fieldName(...).
no setter
error bool
For successful requests, this value is always false.
no setter
hashCode int
The hash code for this object.
no setterinherited
meta ComponentsMeta
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status num
The status of the request.
no setter
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited