DefaultShapeTraits class abstract mixin

Implemented types
Implementers

Constructors

DefaultShapeTraits()

Properties

absoluteBoundingBox Rectangle?
Bounding box of the node in absolute space coordinates.
no setterinherited
absoluteRenderBounds Rectangle?
The actual bounds of a node accounting for drop shadows, thick strokes, and anything else that may fall outside the node's regular bounding box defined in x, y, width, and height.
no setterinherited
blendMode BlendMode
How this node blends with nodes behind it in the scene (see blend mode section for more details).
no setterinherited
boundVariables LayerTraitVariables
A mapping of field to the variables applied to this field.
no setterinherited
componentPropertyReferences Map<String, String>
A mapping of a layer's property to component property name of component properties attached to this node.
no setterinherited
constraints LayoutConstraint?
Horizontal and vertical layout constraints for node.
no setterinherited
effects List<Effect>
An array of effects attached to this node (see effects section for more details).
no setterinherited
explicitVariableModes Map<String, String>
A mapping of variable collection ID to mode ID representing the explicitly set modes for this node.
no setterinherited
exportSettings List<ExportSetting>
An array of export settings representing images to export from the node.
no setterinherited
fillGeometry List<Path>
Only specified if parameter geometry=paths is used.
no setterinherited
fillOverrideTable Map<String, PaintOverride?>
Map from ID to PaintOverride for looking up fill overrides.
no setterinherited
fills List<Paint>
An array of fill paints applied to the node.
no setterinherited
gridChildHorizontalAlign GridChildAlign?
Determines how a GRID frame's child should be aligned in the horizontal direction within its grid area.
no setterinherited
gridChildVerticalAlign GridChildAlign?
Determines how a GRID frame's child should be aligned in the vertical direction within its grid area.
no setterinherited
gridColumnAnchorIndex num
The index of the column that a GRID frame's child should be anchored to.
no setterinherited
gridColumnCount num?
The number of columns in the grid layout.
no setterinherited
gridColumnGap num
The distance between columns in the grid layout.
no setterinherited
gridColumnSpan num
The number of columns that a GRID frame's child should span.
no setterinherited
gridColumnsSizing String?
The string for the CSS grid-template-columns property.
no setterinherited
gridRowAnchorIndex num
The index of the row that a GRID frame's child should be anchored to.
no setterinherited
gridRowCount num?
The number of rows in the grid layout.
no setterinherited
gridRowGap num
The distance between rows in the grid layout.
no setterinherited
gridRowSpan num
The number of rows that a GRID frame's child should span.
no setterinherited
gridRowsSizing String?
The string for the CSS grid-template-rows property.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
A string uniquely identifying this node within the document.
no setterinherited
interactions List<Interaction>
no setterinherited
isMask bool
Does this node mask sibling nodes in front of it?.
no setterinherited
layoutAlign LayoutAlign?
Determines if the layer should stretch along the parent's counter axis.
no setterinherited
layoutGrow LayoutGrow
This property is applicable only for direct children of auto-layout frames, ignored otherwise.
no setterinherited
layoutPositioning LayoutPositioning
Determines whether a layer's size and position should be determined by auto-layout settings or manually adjustable.
no setterinherited
layoutSizingHorizontal LayoutSizing?
The horizontal sizing setting on this auto-layout frame or frame child.
no setterinherited
layoutSizingVertical LayoutSizing?
The vertical sizing setting on this auto-layout frame or frame child.
no setterinherited
locked bool
If true, layer is locked and cannot be edited.
no setterinherited
maskType MaskType?
If this layer is a mask, this property describes the operation used to mask the layer's siblings.
no setterinherited
maxHeight num
The maximum height of the frame.
no setterinherited
maxWidth num
The maximum width of the frame.
no setterinherited
minHeight num
The minimum height of the frame.
no setterinherited
minWidth num
The minimum width of the frame.
no setterinherited
name String
The name given to the node by the user in the tool.
no setterinherited
opacity num
Opacity of the node.
no setterinherited
pluginData Object?
Data written by plugins that is visible only to the plugin that wrote it.
no setterinherited
preserveRatio bool
Keep height and width constrained to same ratio.
no setterinherited
relativeTransform Transform?
The top two rows of a matrix that represents the 2D transform of this node relative to its parent.
no setterinherited
rotation num
The rotation of the node, if not 0.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior ScrollBehavior
How layer should be treated when the frame is resized.
no setterinherited
sharedPluginData Object?
Data written by plugins that is visible to all plugins.
no setterinherited
size Vector?
Width and height of element.
no setterinherited
strokeAlign StrokeAlign?
Position of stroke relative to vector outline, as a string enum.
no setterinherited
strokeCap StrokeCap
A string enum describing the end caps of vector paths.
no setterinherited
strokeDashes List<num>
An array of floating point numbers describing the pattern of dash length and gap lengths that the vector stroke will use when drawn.
no setterinherited
strokeGeometry List<Path>
Only specified if parameter geometry=paths is used.
no setterinherited
strokeJoin StrokeJoin
A string enum with value of "MITER", "BEVEL", or "ROUND", describing how corners in vector paths are rendered.
no setterinherited
strokeMiterAngle num
Only valid if strokeJoin is "MITER".
no setterinherited
strokes List<Paint>
An array of stroke paints applied to the node.
no setterinherited
strokeWeight num
The weight of strokes on the node.
no setterinherited
styles Map<String, String>
A mapping of a StyleType to style ID (see Style) of styles present on this node.
no setterinherited
transitionDuration num?
The duration of the prototyping transition on this node (in milliseconds).
no setterinherited
transitionEasing EasingType?
The easing curve used in the prototyping transition on this node.
no setterinherited
transitionNodeId String?
Node ID of node to transition to in prototyping.
no setterinherited
visible bool
Whether or not the node is visible on the canvas.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited