rateLimitType property
The type of rate limit the user is encountering, based on their seat type.
Implementation
final FigmaRateLimitType rateLimitType;
The type of rate limit the user is encountering, based on their seat type.
final FigmaRateLimitType rateLimitType;