FrameOffset class

Position of a comment relative to the frame to which it is attached.

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @CopyWith.new()
  • @immutable

Constructors

FrameOffset({required String nodeId, required Vector nodeOffset})
const
FrameOffset.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → _$FrameOffsetCWProxy

Available on FrameOffset, provided by the $FrameOffsetCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfFrameOffset.copyWith(...) or instanceOfFrameOffset.copyWith.fieldName(...).
no setter
hashCode int
The hash code for this object.
no setterinherited
nodeId String
Unique id specifying the frame.
final
nodeOffset Vector
2D vector offset within the frame from the top-left corner.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited