GetPage class

Get a paginated list of published components within a team library.

Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()
  • @immutable

Constructors

GetPage({num pageSize = 30, num? after, num? before})
const
GetPage.fromJson(Map<String, Object?> json)
factory

Properties

after num?
Cursor indicating which id after which to start retrieving components for.
final
before num?
Cursor indicating which id before which to start retrieving components for.
final
copyWith → _$GetPageCWProxy

Available on GetPage, provided by the $GetPageCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfGetPage.copyWith(...) or instanceOfGetPage.copyWith.fieldName(...).
no setter
hashCode int
The hash code for this object.
no setterinherited
pageSize num
Number of items to return in a paged list of results.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited