strokeCap property
StrokeCap
get
strokeCap
A string enum describing the end caps of vector paths.
Implementation
StrokeCap get strokeCap;
A string enum describing the end caps of vector paths.
StrokeCap get strokeCap;