size property
Vector?
get
size
Width and height of element.
This is different from the width and height of the bounding box in that
the absolute bounding box represents the element after scaling and
rotation. Only present if geometry=paths is passed.
Implementation
Vector? get size;