ImageFilters class

Image filters to apply to the node.

Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()
  • @immutable

Constructors

ImageFilters({num exposure = 0, num contrast = 0, num saturation = 0, num temperature = 0, num tint = 0, num highlights = 0, num shadows = 0})
const
ImageFilters.fromJson(Map<String, Object?> json)
factory

Properties

contrast num
final
copyWith → _$ImageFiltersCWProxy

Available on ImageFilters, provided by the $ImageFiltersCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfImageFilters.copyWith(...) or instanceOfImageFilters.copyWith.fieldName(...).
no setter
exposure num
final
hashCode int
The hash code for this object.
no setterinherited
highlights num
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturation num
final
shadows num
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
temperature num
final
tint num
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited