Interaction class

An interaction in the Figma viewer, containing a trigger and one or more actions.

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @CopyWith.new()
  • @immutable

Constructors

Interaction({Trigger? trigger, List<Action?> actions = const []})
const
Interaction.fromJson(Map<String, Object?> json)
factory

Properties

actions List<Action?>
The actions that are performed when the trigger is activated.
final
copyWith → _$InteractionCWProxy

Available on Interaction, provided by the $InteractionCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfInteraction.copyWith(...) or instanceOfInteraction.copyWith.fieldName(...).
no setter
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
trigger Trigger?
The user event that initiates the interaction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited