isExtension property
Whether this variable collection is an extension of another variable collection.
Implementation
@JsonKey(includeIfNull: false)
final bool? isExtension;
Whether this variable collection is an extension of another variable collection.
@JsonKey(includeIfNull: false)
final bool? isExtension;