NodeType enum

Inheritance
Available extensions

Values

booleanOperation → const NodeType
component → const NodeType
componentSet → const NodeType
connector → const NodeType
ellipse → const NodeType
embed → const NodeType
frame → const NodeType
group → const NodeType
instance → const NodeType
line → const NodeType
linkUnfurl → const NodeType
rectangle → const NodeType
regularPolygon → const NodeType
section → const NodeType
shapeWithText → const NodeType
slice → const NodeType
star → const NodeType
sticky → const NodeType
table → const NodeType
tableCell → const NodeType
text → const NodeType
textPath → const NodeType
transformGroup → const NodeType
vector → const NodeType
washiTape → const NodeType
widget → const NodeType
document → const NodeType
canvas → const NodeType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NodeType>
A constant List of the values in this enum, in order of their declaration.