NormalBlurEffect class

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @immutable

Constructors

NormalBlurEffect({required EffectType type, required bool visible, required num radius, BlurEffectVariables boundVariables = const BlurEffectVariables()})
const
NormalBlurEffect.fromJson(Map<String, Object?> json)
factory

Properties

blurType BlurType
The string literal 'NORMAL' representing the blur type.
no setteroverride
boundVariables BlurEffectVariables
The variables bound to a particular field on this blur effect.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
radius num
Radius of the blur effect.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type EffectType
Discriminator for Effect types.
finalinherited
visible bool
Whether this blur is active.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited