OnMouseInteractionTrigger class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @CopyWith.new()
  • @immutable

Constructors

OnMouseInteractionTrigger({required TriggerType type})
const
OnMouseInteractionTrigger.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → _$OnMouseInteractionTriggerCWProxy

Available on OnMouseInteractionTrigger, provided by the $OnMouseInteractionTriggerCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfOnMouseInteractionTrigger.copyWith(...) or instanceOfOnMouseInteractionTrigger.copyWith.fieldName(...).
no setter
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type TriggerType
Discriminator for Trigger types.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited