Paint class abstract

Implementers
Annotations
  • @JsonSerializable.new(explicitToJson: true, createFactory: false)
  • @immutable

Constructors

Paint({bool visible = true, num opacity = 1, required BlendMode blendMode})
const
Paint.fromJson(Map<String, Object?> json)
factory

Properties

blendMode BlendMode
How this node blends with nodes behind it in the scene.
final
hashCode int
The hash code for this object.
no setterinherited
opacity num
Overall opacity of paint (colors within the paint can also have opacity values which would blend with this).
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type PaintType
Discriminator for Paint types.
no setter
visible bool
Is the paint enabled?.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited