PublishedVariable class

A Variable is a single design token that defines values for each of the modes in its VariableCollection.

These values can be applied to various kinds of design properties.

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @CopyWith.new()
  • @immutable

Constructors

PublishedVariable({required String id, required String subscribedId, required String name, required String key, required String variableCollectionId, required VariableResolvedDataType resolvedDataType, required DateTime updatedAt})
const
PublishedVariable.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → _$PublishedVariableCWProxy

Available on PublishedVariable, provided by the $PublishedVariableCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfPublishedVariable.copyWith(...) or instanceOfPublishedVariable.copyWith.fieldName(...).
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier of this variable.
final
key String
The key of this variable.
final
name String
The name of this variable.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
resolvedDataType VariableResolvedDataType
The resolved type of the variable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
subscribedId String
The ID of the variable that is used by subscribing files.
final
updatedAt DateTime
The UTC ISO 8601 time at which the variable was last updated.
final
variableCollectionId String
The id of the variable collection that contains this variable.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited