Rectangle class

A rectangle that expresses a bounding box in absolute coordinates.

Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()
  • @immutable

Constructors

Rectangle({required num x, required num y, required num width, required num height})
const
Rectangle.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → _$RectangleCWProxy

Available on Rectangle, provided by the $RectangleCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfRectangle.copyWith(...) or instanceOfRectangle.copyWith.fieldName(...).
no setter
hashCode int
The hash code for this object.
no setterinherited
height num
Height of the rectangle.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
width num
Width of the rectangle.
final
x num
X coordinate of top left corner of the rectangle.
final
y num
Y coordinate of top left corner of the rectangle.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited