layoutGrow property
This property is applicable only for direct children of auto-layout frames, ignored otherwise.
Determines whether a layer should stretch along the parent's primary axis.
A 0 corresponds to a fixed size and 1 corresponds to stretch.
Implementation
@JsonKey(defaultValue: LayoutGrow.fixed)
@override
final LayoutGrow layoutGrow;