pluginData property
Data written by plugins that is visible only to the plugin that wrote it.
Requires the pluginData to include the ID of the plugin.
Implementation
@JsonKey(includeIfNull: false)
@override
final Object? pluginData;
Data written by plugins that is visible only to the plugin that wrote it.
Requires the pluginData to include the ID of the plugin.
@JsonKey(includeIfNull: false)
@override
final Object? pluginData;