relativeTransform property
The top two rows of a matrix that represents the 2D transform of this node relative to its parent.
The bottom row of the matrix is implicitly always (0, 0, 1). Use to
transform coordinates in geometry. Only present if geometry=paths is
passed.
Implementation
@JsonKey(includeIfNull: false)
@override
final Transform? relativeTransform;