sharedPluginData property
Data written by plugins that is visible to all plugins.
Requires the pluginData parameter to include the string "shared".
Implementation
@JsonKey(includeIfNull: false)
@override
final Object? sharedPluginData;
Data written by plugins that is visible to all plugins.
Requires the pluginData parameter to include the string "shared".
@JsonKey(includeIfNull: false)
@override
final Object? sharedPluginData;