ShadowEffect class abstract

Inheritance
Implementers
Annotations
  • @JsonSerializable.new(explicitToJson: true, createFactory: false)
  • @immutable

Constructors

ShadowEffect({required Rgba color, required BlendMode blendMode, required Vector offset, required num radius, num spread = 0, required bool visible, ShadowEffectVariables boundVariables = const ShadowEffectVariables()})
const
ShadowEffect.fromJson(Map<String, Object?> json)
factory

Properties

blendMode BlendMode
Blend mode of the shadow.
final
boundVariables ShadowEffectVariables
The variables bound to a particular field on this shadow effect.
final
color Rgba
The color of the shadow.
final
hashCode int
The hash code for this object.
no setterinherited
offset Vector
How far the shadow is projected in the x and y directions.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
radius num
Radius of the blur effect (applies to shadows as well).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spread num
The distance by which to expand (or contract) the shadow.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type EffectType
Discriminator for Effect types.
no setterinherited
visible bool
Whether this shadow is visible.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited