SubCanvasNode class abstract
- Inheritance
- Implementers
- BooleanOperationNode
- ComponentNode
- ComponentSetNode
- ConnectorNode
- EllipseNode
- EmbedNode
- Frame
- GroupNode
- InstanceNode
- LineNode
- LinkUnfurlNode
- RectangleNode
- RegularPolygonNode
- Section
- SectionNode
- ShapeWithTextNode
- SliceNode
- StarNode
- StickyNode
- TableCellNode
- TableNode
- TextNode
- TextPathNode
- TransformGroupNode
- VectorNode
- WashiTapeNode
- WidgetNode
- Annotations
-
- @JsonSerializable.new(createFactory: false)
- @immutable
Constructors
- SubCanvasNode()
-
const
-
SubCanvasNode.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → NodeType
-
Discriminator for Node types.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited