TeamProjectsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @CopyWith.new()
  • @immutable

Constructors

TeamProjectsResponse({required String name, required List<Project> projects})
const
TeamProjectsResponse.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → _$TeamProjectsResponseCWProxy

Available on TeamProjectsResponse, provided by the $TeamProjectsResponseCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfTeamProjectsResponse.copyWith(...) or instanceOfTeamProjectsResponse.copyWith.fieldName(...).
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
The team's name.
final
projects List<Project>
An array of projects.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited