TextPathTypeStyle class

Mixed-in types
Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @CopyWith.new()
  • @immutable

Constructors

TextPathTypeStyle({String? fontFamily, String? fontPostScriptName, String? fontStyle, bool italic = false, num? fontWeight, num? fontSize, TextCase? textCase, TextAlignHorizontal? textAlignHorizontal, TextAlignVertical? textAlignVertical, num? letterSpacing, List<Paint> fills = const [], Hyperlink? hyperlink, Map<String, num> openTypeFlags = const {}, SemanticWeight? semanticWeight, SemanticItalic? semanticItalic, bool? isOverrideOverTextStyle, TextPathTypeStyleVariables boundVariables = const TextPathTypeStyleVariables()})
const
TextPathTypeStyle.fromJson(Map<String, Object?> json)
factory

Properties

boundVariables TextPathTypeStyleVariables
The variables bound to a particular field on this style.
final
copyWith → _$TextPathTypeStyleCWProxy

Available on TextPathTypeStyle, provided by the $TextPathTypeStyleCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfTextPathTypeStyle.copyWith(...) or instanceOfTextPathTypeStyle.copyWith.fieldName(...).
no setter
fills List<Paint>
An array of fill paints applied to the characters.
final
fontFamily String?
Font family of text (standard name).
final
fontPostScriptName String?
PostScript font name.
final
fontSize num?
Font size in px.
final
fontStyle String?
Describes visual weight or emphasis, such as Bold or Italic.
final
fontWeight num?
Numeric font weight.
final
hashCode int
The hash code for this object.
no setterinherited
Link to a URL or frame.
final
isOverrideOverTextStyle bool?
Whether or not this style has overrides over a text style.
final
italic bool
Whether or not text is italicized.
final
letterSpacing num?
Space between characters in px.
final
openTypeFlags Map<String, num>
A map of OpenType feature flags to 1 or 0, 1 if it is enabled and 0 if it is disabled.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticItalic SemanticItalic?
Indicates how the font style was overridden when there is a text style override.
final
semanticWeight SemanticWeight?
Indicates how the font weight was overridden when there is a text style override.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
textAlignHorizontal TextAlignHorizontal?
Horizontal text alignment as string enum.
final
textAlignVertical TextAlignVertical?
Vertical text alignment as string enum.
final
textCase TextCase?
Text casing applied to the node, default is the original casing.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited