semanticWeight property
Indicates how the font weight was overridden when there is a text style override.
Implementation
@JsonKey(includeIfNull: false)
@override
final SemanticWeight? semanticWeight;
Indicates how the font weight was overridden when there is a text style override.
@JsonKey(includeIfNull: false)
@override
final SemanticWeight? semanticWeight;