TransitionSourceTrait class abstract mixin

Implementers

Constructors

TransitionSourceTrait()

Properties

hashCode int
The hash code for this object.
no setterinherited
interactions List<Interaction>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionDuration num?
The duration of the prototyping transition on this node (in milliseconds).
no setter
transitionEasing EasingType?
The easing curve used in the prototyping transition on this node.
no setter
transitionNodeId String?
Node ID of node to transition to in prototyping.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited