UpdateMediaRuntimeSkipToAction class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @CopyWith.new()
  • @immutable

Constructors

UpdateMediaRuntimeSkipToAction({String? destinationId, required num newTimestamp})
const
UpdateMediaRuntimeSkipToAction.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → _$UpdateMediaRuntimeSkipToActionCWProxy

Available on UpdateMediaRuntimeSkipToAction, provided by the $UpdateMediaRuntimeSkipToActionCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfUpdateMediaRuntimeSkipToAction.copyWith(...) or instanceOfUpdateMediaRuntimeSkipToAction.copyWith.fieldName(...).
no setter
destinationId String?
The destinationId is the node ID of the media node to update.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
mediaAction MediaAction
Discriminator for UpdateMediaRuntimeAction types.
no setteroverride
newTimestamp num
The new time to skip to in seconds.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type ActionType
Discriminator for Action types.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited