VariableValue typedef

VariableValue = Object

The value for the variable.

The value must match the variable's type. If setting to a variable alias, the alias must resolve to this type. If overriding a value, the value type must match the variable's type. If removing an overridden value, the value must be null.

Implementation

typedef VariableValue = Object;