VersionsResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @CopyWith.new()
  • @immutable

Constructors

VersionsResponse({required List<Version> versions, required ResponsePagination pagination})
const
VersionsResponse.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → _$VersionsResponseCWProxy

Available on VersionsResponse, provided by the $VersionsResponseCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfVersionsResponse.copyWith(...) or instanceOfVersionsResponse.copyWith.fieldName(...).
no setter
hashCode int
The hash code for this object.
no setterinherited
pagination ResponsePagination
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
versions List<Version>
An array of versions.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited