ConnectorTextBackground class
- Mixed-in types
- Available extensions
- Annotations
-
- @JsonSerializable.new()
- @CopyWith.new()
- @immutable
Constructors
Properties
- copyWith → _$ConnectorTextBackgroundCWProxy
-
Available on ConnectorTextBackground, provided by the $ConnectorTextBackgroundCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfConnectorTextBackground.copyWith(...)orinstanceOfConnectorTextBackground.copyWith.fieldName(...).no setter - cornerRadius → num
-
Radius of each corner if a single radius is set for all corners.
final
- cornerSmoothing → num
-
A value that lets you control how "smooth" the corners are.
final
-
fills
→ List<
Paint> -
An array of fill paints applied to the node.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
-
rectangleCornerRadii
→ List<
num> -
Array of length 4 of the radius of each corner of the frame, starting in
the top left and proceeding clockwise.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited -
styles
→ Map<
String, String> -
A mapping of a StyleType to style ID (see Style) of styles present on this
node.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited