rectangleCornerRadii property
Array of length 4 of the radius of each corner of the frame, starting in the top left and proceeding clockwise.
Values are given in the order top-left, top-right, bottom-right, bottom-left.
Implementation
@JsonKey(defaultValue: [])
@override
final List<num> rectangleCornerRadii;