Properties
-
cornerRadius
→ num
-
Radius of each corner if a single radius is set for all corners.
no setter
-
cornerSmoothing
→ num
-
A value that lets you control how "smooth" the corners are.
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
rectangleCornerRadii
→ List<num>
-
Array of length 4 of the radius of each corner of the frame, starting in
the top left and proceeding clockwise.
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited