Implemented types
Implementers
Properties
absoluteBoundingBox
→ Rectangle ?
Bounding box of the node in absolute space coordinates.
no setter inherited
absoluteRenderBounds
→ Rectangle ?
The actual bounds of a node accounting for drop shadows, thick strokes,
and anything else that may fall outside the node's regular bounding box
defined in x, y, width, and height.
no setter inherited
blendMode
→ BlendMode
How this node blends with nodes behind it in the scene (see blend mode
section for more details).
no setter inherited
boundVariables
→ LayerTraitVariables
A mapping of field to the variables applied to this field.
no setter inherited
componentPropertyReferences
→ Map <String , String >
A mapping of a layer's property to component property name of component
properties attached to this node.
no setter inherited
constraints
→ LayoutConstraint ?
Horizontal and vertical layout constraints for node.
no setter inherited
effects
→ List <Effect >
An array of effects attached to this node (see effects section for more
details).
no setter inherited
explicitVariableModes
→ Map <String , String >
A mapping of variable collection ID to mode ID representing the explicitly
set modes for this node.
no setter inherited
exportSettings
→ List <ExportSetting >
An array of export settings representing images to export from the node.
no setter inherited
fillGeometry
→ List <Path >
Only specified if parameter geometry=paths is used.
no setter inherited
fillOverrideTable
→ Map <String , PaintOverride ? >
Map from ID to PaintOverride for looking up fill overrides.
no setter inherited
fills
→ List <Paint >
An array of fill paints applied to the node.
no setter inherited
gridChildHorizontalAlign
→ GridChildAlign ?
Determines how a GRID frame's child should be aligned in the horizontal
direction within its grid area.
no setter inherited
gridChildVerticalAlign
→ GridChildAlign ?
Determines how a GRID frame's child should be aligned in the vertical
direction within its grid area.
no setter inherited
gridColumnAnchorIndex
→ num
The index of the column that a GRID frame's child should be anchored to.
no setter inherited
gridColumnCount
→ num ?
The number of columns in the grid layout.
no setter inherited
gridColumnGap
→ num
The distance between columns in the grid layout.
no setter inherited
gridColumnSpan
→ num
The number of columns that a GRID frame's child should span.
no setter inherited
gridColumnsSizing
→ String ?
The string for the CSS grid-template-columns property.
no setter inherited
gridRowAnchorIndex
→ num
The index of the row that a GRID frame's child should be anchored to.
no setter inherited
gridRowCount
→ num ?
The number of rows in the grid layout.
no setter inherited
gridRowGap
→ num
The distance between rows in the grid layout.
no setter inherited
gridRowSpan
→ num
The number of rows that a GRID frame's child should span.
no setter inherited
gridRowsSizing
→ String ?
The string for the CSS grid-template-rows property.
no setter inherited
hashCode
→ int
The hash code for this object.
no setter inherited
id
→ String
A string uniquely identifying this node within the document.
no setter inherited
interactions
→ List <Interaction >
no setter inherited
isMask
→ bool
Does this node mask sibling nodes in front of it?.
no setter inherited
layoutAlign
→ LayoutAlign ?
Determines if the layer should stretch along the parent's counter axis.
no setter inherited
layoutGrow
→ LayoutGrow
This property is applicable only for direct children of auto-layout
frames, ignored otherwise.
no setter inherited
layoutPositioning
→ LayoutPositioning
Determines whether a layer's size and position should be determined by
auto-layout settings or manually adjustable.
no setter inherited
layoutSizingHorizontal
→ LayoutSizing ?
The horizontal sizing setting on this auto-layout frame or frame child.
no setter inherited
layoutSizingVertical
→ LayoutSizing ?
The vertical sizing setting on this auto-layout frame or frame child.
no setter inherited
locked
→ bool
If true, layer is locked and cannot be edited.
no setter inherited
maskType
→ MaskType ?
If this layer is a mask, this property describes the operation used to
mask the layer's siblings.
no setter inherited
maxHeight
→ num
The maximum height of the frame.
no setter inherited
maxWidth
→ num
The maximum width of the frame.
no setter inherited
minHeight
→ num
The minimum height of the frame.
no setter inherited
minWidth
→ num
The minimum width of the frame.
no setter inherited
name
→ String
The name given to the node by the user in the tool.
no setter inherited
opacity
→ num
Opacity of the node.
no setter inherited
pluginData
→ Object ?
Data written by plugins that is visible only to the plugin that wrote it.
no setter inherited
preserveRatio
→ bool
Keep height and width constrained to same ratio.
no setter inherited
relativeTransform
→ Transform ?
The top two rows of a matrix that represents the 2D transform of this node
relative to its parent.
no setter inherited
rotation
→ num
The rotation of the node, if not 0.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
scrollBehavior
→ ScrollBehavior
How layer should be treated when the frame is resized.
no setter inherited
sharedPluginData
→ Object ?
Data written by plugins that is visible to all plugins.
no setter inherited
size
→ Vector ?
Width and height of element.
no setter inherited
strokeAlign
→ StrokeAlign ?
Position of stroke relative to vector outline, as a string enum.
no setter inherited
strokeCap
→ StrokeCap
A string enum describing the end caps of vector paths.
no setter inherited
strokeDashes
→ List <num >
An array of floating point numbers describing the pattern of dash length
and gap lengths that the vector stroke will use when drawn.
no setter inherited
strokeGeometry
→ List <Path >
Only specified if parameter geometry=paths is used.
no setter inherited
strokeJoin
→ StrokeJoin
A string enum with value of "MITER", "BEVEL", or "ROUND", describing how
corners in vector paths are rendered.
no setter inherited
strokeMiterAngle
→ num
Only valid if strokeJoin is "MITER".
no setter inherited
strokes
→ List <Paint >
An array of stroke paints applied to the node.
no setter inherited
strokeWeight
→ num
The weight of strokes on the node.
no setter inherited
styles
→ Map <String , String >
A mapping of a StyleType to style ID (see Style) of styles present on this
node.
no setter inherited
transitionDuration
→ num ?
The duration of the prototyping transition on this node (in milliseconds).
no setter inherited
transitionEasing
→ EasingType ?
The easing curve used in the prototyping transition on this node.
no setter inherited
transitionNodeId
→ String ?
Node ID of node to transition to in prototyping.
no setter inherited
visible
→ bool
Whether or not the node is visible on the canvas.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited