FigmaRateLimitException class
Properties
-
code
→ int
-
HTTP status code.
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
message
→ String
-
Error message.
finalinherited
-
planTier
→ FigmaPlanTier
-
The current plan tier of the resource the user is requesting.
final
-
rateLimitType
→ FigmaRateLimitType
-
The type of rate limit the user is encountering, based on their seat type.
final
-
retryAfter
→ int
-
In seconds, how long before you should retry sending the request.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
upgradeLink
→ String
-
A link to either the /pricing or /settings pages depending on the
plan/seat of the user.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited