FileVersionUpdatePayload class
- Inheritance
-
- Object
- WebhookPayload
- FileVersionUpdatePayload
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
- @CopyWith.new()
- @immutable
Constructors
- FileVersionUpdatePayload({required String passcode, required DateTime timestamp, required String webhookId, required DateTime createdAt, String? description, required String fileKey, required String fileName, required User triggeredBy, required String versionId})
-
const
-
FileVersionUpdatePayload.fromJson(Map<
String, Object?> json) -
factory
Properties
- copyWith → _$FileVersionUpdatePayloadCWProxy
-
Available on FileVersionUpdatePayload, provided by the $FileVersionUpdatePayloadCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfFileVersionUpdatePayload.copyWith(...)orinstanceOfFileVersionUpdatePayload.copyWith.fieldName(...).no setter - createdAt → DateTime
-
UTC ISO 8601 timestamp of when the version was created.
final
- description → String?
-
Description of the version in the version history.
final
- eventType → WebhookEvent
-
Discriminator for WebhookPayload types.
no setteroverride
- fileKey → String
-
The key of the file that was updated.
final
- fileName → String
-
The name of the file that was updated.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- passcode → String
-
The passcode specified when the webhook was created, should match what was
initially provided.
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - timestamp → DateTime
-
UTC ISO 8601 timestamp of when the event was triggered.
finalinherited
- triggeredBy → User
-
The user that created the named version and triggered this event.
final
- versionId → String
-
ID of the published version.
final
- webhookId → String
-
The id of the webhook that caused the callback.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited