- Implementers
Constructors
Properties
- clipsContent → bool
-
Whether or not this node clip content outside of its bounds.
no setter
- counterAxisAlignContent → CounterAxisAlignContent
-
Determines how the auto-layout frame’s wrapped tracks should be aligned in
the counter axis direction.
no setter
- counterAxisAlignItems → CounterAxisAlignItems
-
Determines how the auto-layout frame's children should be aligned in the
counter axis direction.
no setter
- counterAxisSizingMode → CounterAxisSizingMode
-
Whether the counter axis has a fixed length (determined by the user) or an
automatic length (determined by the layout engine).
no setter
- counterAxisSpacing → num?
-
The distance between wrapped tracks of an auto-layout frame.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemReverseZIndex → bool
-
Determines the canvas stacking order of layers in this frame.
no setter
- itemSpacing → num
-
The distance between children of the frame.
no setter
-
layoutGrids
→ List<
LayoutGrid> -
An array of layout grids attached to this node (see layout grids section
for more details).
no setter
- layoutMode → LayoutMode
-
Whether this layer uses auto-layout to position its children.
no setter
- layoutWrap → LayoutWrap?
-
Whether this auto-layout frame has wrapping enabled.
no setter
- overflowDirection → OverflowDirection
-
Whether a node has primary axis scrolling, horizontal or vertical.
no setter
- paddingBottom → num
-
The padding between the bottom border of the frame and its children.
no setter
- paddingLeft → num
-
The padding between the left border of the frame and its children.
no setter
- paddingRight → num
-
The padding between the right border of the frame and its children.
no setter
- paddingTop → num
-
The padding between the top border of the frame and its children.
no setter
- primaryAxisAlignItems → PrimaryAxisAlignItems
-
Determines how the auto-layout frame's children should be aligned in the
primary axis direction.
no setter
- primaryAxisSizingMode → PrimaryAxisSizingMode
-
Whether the primary axis has a fixed length (determined by the user) or an
automatic length (determined by the layout engine).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokesIncludedInLayout → bool
-
Determines whether strokes are included in layout calculations.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited