InnerShadowEffect class
- Inheritance
-
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
- @immutable
Properties
-
blendMode
→ BlendMode
-
Blend mode of the shadow.
finalinherited
-
boundVariables
→ ShadowEffectVariables
-
The variables bound to a particular field on this shadow effect.
finalinherited
-
color
→ Rgba
-
The color of the shadow.
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
offset
→ Vector
-
How far the shadow is projected in the x and y directions.
finalinherited
-
props
→ List<Object?>
-
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
-
radius
→ num
-
Radius of the blur effect (applies to shadows as well).
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
spread
→ num
-
The distance by which to expand (or contract) the shadow.
finalinherited
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
-
type
→ EffectType
-
A string literal representing the effect's type.
no setteroverride
-
visible
→ bool
-
Whether this shadow is visible.
finalinherited