LayoutGridVariables class
The variables bound to a particular field on this layout grid.
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
- @CopyWith.new()
- @immutable
Constructors
- LayoutGridVariables({VariableAlias? gutterSize, VariableAlias? numSections, VariableAlias? sectionSize, VariableAlias? offset})
-
const
-
LayoutGridVariables.fromJson(Map<
String, Object?> json) -
factory
Properties
- copyWith → _$LayoutGridVariablesCWProxy
-
Available on LayoutGridVariables, provided by the $LayoutGridVariablesCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfLayoutGridVariables.copyWith(...)orinstanceOfLayoutGridVariables.copyWith.fieldName(...).no setter - gutterSize → VariableAlias?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- numSections → VariableAlias?
-
final
- offset → VariableAlias?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionSize → VariableAlias?
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited