LocalVariableCollection class
A grouping of related Variable objects each with the same modes.
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
- @CopyWith.new()
- @immutable
Constructors
-
LocalVariableCollection({required String id, required String name, required String key, required List<
Mode> modes, required String defaultModeId, required bool remote, bool? isExtension, String? parentVariableCollectionId, String? rootVariableCollectionId, Map<String, Map< variableOverrides = const {}, required List<String, VariableValue> >String> variableIds}) -
const
-
LocalVariableCollection.fromJson(Map<
String, Object?> json) -
factory
Properties
- copyWith → _$LocalVariableCollectionCWProxy
-
Available on LocalVariableCollection, provided by the $LocalVariableCollectionCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfLocalVariableCollection.copyWith(...)orinstanceOfLocalVariableCollection.copyWith.fieldName(...).no setter - defaultModeId → String
-
The id of the default mode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether this variable collection is hidden when publishing the current
file as a library.
final
- id → String
-
The unique identifier of this variable collection.
final
- isExtension → bool?
-
Whether this variable collection is an extension of another variable
collection.
final
- key → String
-
The key of this variable collection.
final
-
modes
→ List<
Mode> -
The modes of this variable collection.
final
- name → String
-
The name of this variable collection.
final
- parentVariableCollectionId → String?
-
The id of the parent variable collection that this variable collection is
an extension of.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- remote → bool
-
Whether this variable collection is remote.
final
- rootVariableCollectionId → String?
-
The id of the root variable collection in the extension chain.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited -
variableIds
→ List<
String> -
The ids of the variables in the collection.
final
-
variableOverrides
→ Map<
String, Map< String, VariableValue> > -
The overrides for the variables in this variable collection as a map of
variable ids to a map of mode ids to variable values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited