LocalVariablesMeta class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
- @CopyWith.new()
- @immutable
Constructors
-
LocalVariablesMeta({required Map<
String, LocalVariable> variables, required Map<String, LocalVariableCollection> variableCollections}) -
const
-
LocalVariablesMeta.fromJson(Map<
String, Object?> json) -
factory
Properties
- copyWith → _$LocalVariablesMetaCWProxy
-
Available on LocalVariablesMeta, provided by the $LocalVariablesMetaCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfLocalVariablesMeta.copyWith(...)orinstanceOfLocalVariablesMeta.copyWith.fieldName(...).no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited -
variableCollections
→ Map<
String, LocalVariableCollection> -
A map of variable collection ids to variable collections.
final
-
variables
→ Map<
String, LocalVariable> -
A map of variable ids to variables.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited