Properties
-
fills
→ List<Paint>
-
An array of fill paints applied to the node.
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
styles
→ Map<String, String>
-
A mapping of a StyleType to style ID (see Style) of styles present on this
node.
no setter
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited