NodesResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
- @CopyWith.new()
- @immutable
Constructors
-
NodesResponse({required String name, required Role role, required DateTime lastModified, required EditorType editorType, required String thumbnailUrl, required String version, required Map<
String, NodeMeta> nodes}) -
const
-
NodesResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- copyWith → _$NodesResponseCWProxy
-
Available on NodesResponse, provided by the $NodesResponseCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfNodesResponse.copyWith(...)orinstanceOfNodesResponse.copyWith.fieldName(...).no setter - editorType → EditorType
-
The type of editor associated with this file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastModified → DateTime
-
The UTC ISO 8601 time at which the file was last modified.
final
- name → String
-
The name of the file as it appears in the editor.
final
-
nodes
→ Map<
String, NodeMeta> -
A mapping from node IDs to node metadata.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- role → Role
-
The role of the user making the API request in relation to the file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - thumbnailUrl → String
-
A URL to a thumbnail image of the file.
final
- version → String
-
The version number of the file.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited