PostComment class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
- @CopyWith.new()
- @immutable
Constructors
- PostComment({required String message, String? commentId, ClientMeta? clientMeta})
-
const
-
PostComment.fromJson(Map<
String, Object?> json) -
factory
Properties
- clientMeta → ClientMeta?
-
The position where to place the comment.
final
- commentId → String?
-
The ID of the comment to reply to, if any.
final
- copyWith → _$PostCommentCWProxy
-
Available on PostComment, provided by the $PostCommentCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfPostComment.copyWith(...)orinstanceOfPostComment.copyWith.fieldName(...).no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The text contents of the comment to post.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited