ProjectMetaResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new()
- @CopyWith.new()
- @immutable
Constructors
Properties
- copyWith → _$ProjectMetaResponseCWProxy
-
Available on ProjectMetaResponse, provided by the $ProjectMetaResponseCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfProjectMetaResponse.copyWith(...)orinstanceOfProjectMetaResponse.copyWith.fieldName(...).no setter - createdAt → DateTime
-
The UTC ISO 8601 time at which the project was created.
final
- fileCount → int
-
The number of files in the project.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier of the project.
final
- name → String
-
The name of the project.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - thumbnailUrl → String?
-
A URL to a thumbnail image of the project.
final
- updatedAt → DateTime
-
The UTC ISO 8601 time at which the project was last updated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited