SliceNode class
- Inheritance
-
- Object
- Node
- SubCanvasNode
- SliceNode
- Mixed-in types
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
- @CopyWith.new()
- @immutable
Constructors
-
SliceNode({required String id, required String name, bool visible = true, bool locked = false, required ScrollBehavior scrollBehavior, num rotation = 0, Map<
String, String> componentPropertyReferences = const {}, Object? pluginData, LayerTraitVariables boundVariables = const LayerTraitVariables(), Map<String, String> explicitVariableModes = const {}}) -
const
-
SliceNode.fromJson(Map<
String, Object?> json) -
factory
Properties
- boundVariables → LayerTraitVariables
-
A mapping of field to the variables applied to this field.
final
-
componentPropertyReferences
→ Map<
String, String> -
A mapping of a layer's property to component property name of component
properties attached to this node.
final
- copyWith → _$SliceNodeCWProxy
-
Available on SliceNode, provided by the $SliceNodeCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfSliceNode.copyWith(...)orinstanceOfSliceNode.copyWith.fieldName(...).no setter -
explicitVariableModes
→ Map<
String, String> -
A mapping of variable collection ID to mode ID representing the explicitly
set modes for this node.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
A string uniquely identifying this node within the document.
final
- locked → bool
-
If true, layer is locked and cannot be edited.
final
- name → String
-
The name given to the node by the user in the tool.
final
- pluginData → Object?
-
Data written by plugins that is visible only to the plugin that wrote it.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- rotation → num
-
The rotation of the node, if not 0.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollBehavior → ScrollBehavior
-
How layer should be treated when the frame is resized.
final
-
Data written by plugins that is visible to all plugins.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → NodeType
-
The type of this node, represented by the string literal "SLICE".
no setteroverride
- visible → bool
-
Whether or not the node is visible on the canvas.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited