absoluteRenderBounds property
The actual bounds of a node accounting for drop shadows, thick strokes,
and anything else that may fall outside the node's regular bounding box
defined in x, y, width, and height.
The x and y inside this property represent the absolute position of
the node on the page. This value will be null if the node is invisible.
Implementation
@override
final Rectangle? absoluteRenderBounds;