boundVariables property
A mapping of field to the variables applied to this field.
Most fields will only map to a single VariableAlias. However, for
properties like fills, strokes, size, componentProperties, and
textRangeFills, it is possible to have multiple variables bound to the
field.
Implementation
@override
final LayerTraitVariables boundVariables;