transitionDuration property
The duration of the prototyping transition on this node (in milliseconds).
This will override the default transition duration on the prototype, for this node.
Implementation
@JsonKey(includeIfNull: false)
@override
final num? transitionDuration;